XmlSer
======

.. currentmodule:: wwt_data_formats

.. autoclass:: XmlSer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~XmlSer.ATTRIBUTE
      ~XmlSer.INNER
      ~XmlSer.INNER_LIST
      ~XmlSer.NS_TO_ATTR
      ~XmlSer.TEXT_ELEM
      ~XmlSer.WRAPPED_INNER
      ~XmlSer.WRAPPED_INNER_LIST

   .. rubric:: Methods Summary

   .. autosummary::

      ~XmlSer.attr
      ~XmlSer.inner
      ~XmlSer.inner_list
      ~XmlSer.ns_to_attr
      ~XmlSer.text_elem
      ~XmlSer.wrapped_inner
      ~XmlSer.wrapped_inner_list

   .. rubric:: Attributes Documentation

   .. autoattribute:: ATTRIBUTE
   .. autoattribute:: INNER
   .. autoattribute:: INNER_LIST
   .. autoattribute:: NS_TO_ATTR
   .. autoattribute:: TEXT_ELEM
   .. autoattribute:: WRAPPED_INNER
   .. autoattribute:: WRAPPED_INNER_LIST

   .. rubric:: Methods Documentation

   .. automethod:: attr
   .. automethod:: inner
   .. automethod:: inner_list
   .. automethod:: ns_to_attr
   .. automethod:: text_elem
   .. automethod:: wrapped_inner
   .. automethod:: wrapped_inner_list
